@@ -18,7 +18,7 @@
 
 """This module represents the Telugu language.
 
-.. seealso:: http://en.wikipedia.org/wiki/Telugu_language
+.. seealso:: :wp:`Telugu_language`
 """
 
 
@@ -29,5 +29,5 @@ class te(common.Common):
     """This class represents Telugu."""
 
     ignoretests = {
-        'all': ["simplecaps", "startcaps"],
+        "all": ["simplecaps", "startcaps"],
     }
