@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2006-2010 Zuza Software Foundation
 #
@@ -21,7 +20,7 @@
 
 from lxml import etree
 
-from translate.misc.xml_helpers import setXMLlang, getXMLspace
+from translate.misc.xml_helpers import getXMLspace, setXMLlang
 from translate.storage import lisa
 
 
@@ -36,8 +35,6 @@ class tbxunit(lisa.LISAunit):
 
     def createlanguageNode(self, lang, text, purpose):
         """returns a langset xml Element setup with given parameters"""
-        if isinstance(text, bytes):
-            text = text.decode("utf-8")
         langset = etree.Element(self.languageNode)
         setXMLlang(langset, lang)
         tig = etree.SubElement(langset, "tig")  # or ntig with termGrp inside
@@ -51,6 +48,9 @@ class tbxunit(lisa.LISAunit):
         # The id attribute is optional
         return self.xmlelement.get("id") or self.source
 
+    def setid(self, value):
+        return self.xmlelement.set("id", value)
+
     def removenotes(self, origin=None):
         """Remove all the translator notes."""
         notes = self.xmlelement.iterdescendants(self.namespaced("note"))
@@ -66,8 +66,6 @@ class tbxunit(lisa.LISAunit):
             text = text.strip()
         if not text:
             return
-        if isinstance(text, bytes):
-            text = text.decode("utf-8")
         note = etree.SubElement(self.xmlelement, self.namespaced("note"))
         note.text = text
         if origin:
@@ -82,28 +80,30 @@ class tbxunit(lisa.LISAunit):
         :rtype: List
         """
         note_nodes = []
-        if origin == 'pos':
+        if origin == "pos":
             note_nodes = self.xmlelement.iterdescendants(self.namespaced("termNote"))
-        elif origin == 'definition':
+        elif origin == "definition":
             note_nodes = self.xmlelement.iterdescendants(self.namespaced("descrip"))
         else:
             note_nodes = self.xmlelement.iterdescendants(self.namespaced("note"))
         # TODO: consider using xpath to construct initial_list directly
         # or to simply get the correct text from the outset (just remember to
         # check for duplication.
-        initial_list = [lisa.getText(note,
-                                     getXMLspace(self.xmlelement,
-                                                 self._default_xml_space))
-                        for note in note_nodes]
+        initial_list = [
+            lisa.getText(note, getXMLspace(self.xmlelement, self._default_xml_space))
+            for note in note_nodes
+        ]
 
         # Remove duplicate entries from list:
         dictset = {}
-        note_list = [dictset.setdefault(note, note) for note in initial_list if note not in dictset]
-
-        return note_list
+        return [
+            dictset.setdefault(note, note)
+            for note in initial_list
+            if note not in dictset
+        ]
 
     def getnotes(self, origin=None):
-        return '\n'.join(self._getnotelist(origin=origin))
+        return "\n".join(self._getnotelist(origin=origin))
 
 
 class tbxfile(lisa.LISAfile):
@@ -115,7 +115,7 @@ class tbxfile(lisa.LISAfile):
     Extensions = ["tbx"]
     rootNode = "martif"
     bodyNode = "body"
-    XMLskeleton = '''<?xml version="1.0"?>
+    XMLskeleton = """<?xml version="1.0"?>
 <!DOCTYPE martif PUBLIC "ISO 12200:1999A//DTD MARTIF core (DXFcdV04)//EN" "TBXcdv04.dtd">
 <martif type="TBX">
 <martifHeader>
@@ -124,7 +124,8 @@ class tbxfile(lisa.LISAfile):
 </fileDesc>
 </martifHeader>
 <text><body></body></text>
-</martif>'''
+</martif>"""
+    XMLindent = {"indent": "    ", "toplevel": False}
 
     def addheader(self):
         """Initialise headers with TBX specific things."""
