@@ -255,7 +255,7 @@ foo: "Hello \"World\"."
         assert store.units[0].source == 'Hello "World".'
         assert (
             bytes(store)
-            == br"""foo: "Hello \"World\"."
+            == rb"""foo: "Hello \"World\"."
 """
         )
 
@@ -272,7 +272,7 @@ foo: "Hello \n World."
         assert store.units[0].source == "Hello \n World."
         assert (
             bytes(store)
-            == br"""foo: "Hello \n World."
+            == rb"""foo: "Hello \n World."
 """
         )
 
@@ -422,6 +422,48 @@ location_batch:
 """
         )
 
+    def test_remove(self):
+        data = """test:
+  1:
+    one: one
+    two: two
+  2:
+    three: three
+    four: four
+"""
+        store = self.StoreClass()
+        store.parse(data)
+        assert len(store.units) == 4
+        assert bytes(store).decode() == data
+        store.removeunit(store.units[0])
+        assert (
+            bytes(store).decode()
+            == """test:
+  1:
+    two: two
+  2:
+    three: three
+    four: four
+"""
+        )
+        store.removeunit(store.units[0])
+        assert (
+            bytes(store).decode()
+            == """test:
+  2:
+    three: three
+    four: four
+"""
+        )
+        store.removeunit(store.units[-1])
+        assert (
+            bytes(store).decode()
+            == """test:
+  2:
+    three: three
+"""
+        )
+
 
 class TestRubyYAMLResourceStore(test_monolingual.TestMonolingualStore):
     StoreClass = yaml.RubyYAMLFile
@@ -458,7 +500,8 @@ class TestRubyYAMLResourceStore(test_monolingual.TestMonolingualStore):
         store.parse(data)
         assert bytes(store) == data.encode("ascii")
 
-    def test_invalid_value(self):
+    @staticmethod
+    def test_invalid_value():
         store = yaml.YAMLFile()
         with pytest.raises(base.ParseError):
             store.parse('val: "\\u string"')
@@ -511,3 +554,21 @@ class TestRubyYAMLResourceStore(test_monolingual.TestMonolingualStore):
         for unit in update.units:
             store.addunit(unit)
         assert bytes(store).decode("ascii") == changed
+
+    def test_add(self):
+        original = """en:
+"""
+        changed = """en:
+  days_on:
+  - Sunday
+  - Monday
+"""
+        store = self.StoreClass()
+        store.parse(original)
+        unit = self.StoreClass.UnitClass("Sunday")
+        unit.setid("days_on[0]")
+        store.addunit(unit)
+        unit = self.StoreClass.UnitClass("Monday")
+        unit.setid("days_on[1]")
+        store.addunit(unit)
+        assert bytes(store).decode("ascii") == changed
